@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-Drummer-Tiny);
 
@@ -57,12 +57,7 @@ has ga_slide_num => (is => 'ro', default => sub { 67 });
 
 sub BUILD {
     my ($self, $args) = @_;
-    # TODO install-enable tabla soundfont?
-}
-
-sub DEMOLISH {
-    my ($self, $in_global_destruction) = @_;
-    # TODO disable tabla soundfont?
+    $self->set_channel(0);
 }
 
 
@@ -198,7 +193,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -331,8 +326,6 @@ possible properties of L<MIDI::Drummer::Tiny>.
 
 =for Pod::Coverage BUILD
 
-=for Pod::Coverage DEMOLISH
-
 =head2 tun
 
   $tabla->tun;
